@@ -4,12 +4,17 @@ from trytond.pool import PoolMeta, Pool
 from trytond.transaction import Transaction
 from trytond.tools import grouped_slice
 
-__all__ = ['InvoiceLine']
-
 
 class InvoiceLine(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
 
+    @classmethod
+    def copy(cls, lines, default=None):
+        default = default.copy() if default is not None else {}
+        default.setdefault('project_invoice_works')
+        default.setdefault('project_invoice_progresses')
+        return super().copy(lines, default=default)
+
     @classmethod
     def delete(cls, lines):
         pool = Pool()
